-- trim - Removes leading or trailing whitespace
function trim ( s )
	return string.gsub( s, "^%s*(.-)%s*$", "%1" )
end

-- stripQuotes - Used to strip quotes from strings
function stripQuotes( s )
	return string.gsub( s, "^[\"]*(.-)[\"]*$", "%1" )
end


-- splitArgs - Used for splitting console arguments, will obey quotation marks
function splitArgs( args )
	local argv = {}
	local argc = 0
	local quoteFlag = false
	local strStore = ""
	
	for a in string.gfind( args, "[%a%p%d]+") do
		if a ~= nil then
			if quoteFlag == false then
				if string.sub( a, 1, 1 ) == "\"" and string.sub( a, -1, -1 ) ~= "\"" then -- If we're beginning a quote
					quoteFlag = true
					strStore = a -- Since this is the beginning, assign the store the beginning
				else
					table.insert( argv, a )
					argc = argc + 1
				end
			else -- If quoteFlag is true
				if string.sub( a, -1, -1 ) == "\"" then -- If we're ending our quote
					quoteFlag = false
					strStore = strStore .. " " .. a
					strStore = stripQuotes( strStore )
					table.insert( argv, strStore )
					argc = argc + 1
				else
					strStore = strStore .. " " .. a -- Add to our store
				end
			end
		end
	end
	
	return argv, argc
end

-- print_functioncall - Pass this the name of the function in a string and 
-- all the arguments of a function to get a helpful debug output of the function call
-- EXAMPLE OUTPUT:
-- [ULX] Debug function call: sendTextAndAnimate( (number)1, (number)10, 
-- (number)0, (number)0.3, (number)0.05, (number)0.51, (number)255, (number)255, 
-- (number)255, (string)7. Exit, (string)ChatFont, (number)60, (number)0.5, (number)0.5, 
-- (number)0.5, (number)0.3,  )
function print_functioncall( function_name, ... )
	_Msg( "[ULX] Debug function call: " .. function_name .. "( " )
	for i=1, table.getn( arg ) do
		_Msg( "(" .. type( arg[ i ] ) .. ")" .. tostring( arg[ i ] ) .. ", " )
	end
	_Msg( " )\n" )
end

function debug( text )
	--if DEBUG_MODE then
		_Msg( "[ULX] Debug: " .. text .. "\n" )
	--end
end

function error_msg( text )
	_Msg( "[ULX] ERROR: " .. text .. "\n" )
end

-- sendText - sends the text in the specified format ( used for menus )
function sendText( userid, key, posx, posy, r, g, b, text, font, timeout, fadein, fadeout )
	_GModText_Start( font )
		_GModText_SetPos( posx, posy )
		_GModText_SetColor( r, g, b, 255 )
		_GModText_SetTime( timeout, fadein, fadeout )
		_GModText_SetText( text )
		_GModText_SetDelay(0)
		_GModText_AllowOffscreen( false )
	_GModText_Send( userid, key )
end

-- sendTextAnimate - animates the text ( you have to define the text with sendText or sendTextAndAnimate first! )
function sendTextAnimate( userid, key, posx, posy, r, g, b, font, length, ease )
	_GModText_Start( font )
		_GModText_SetPos( posx, posy )
		_GModText_SetColor( r, g, b, 255 )
		_GModText_AllowOffscreen( false )
	_GModText_SendAnimate( userid, key, length, ease )
end

-- sendTextAndAnimate - sends and animates the text in the specified format ( used for menus )
function sendTextAndAnimate( userid, key, begPosx, begPosy, posx, posy, r, g, b, text, font, timeout, fadein, fadeout, length, ease )
	_GModText_Start( font )
		_GModText_SetPos( begPosx, begPosy )
		_GModText_SetColor( r, g, b, 255 )
		_GModText_SetTime( timeout, fadein, fadeout )
		_GModText_SetText( text )
		_GModText_SetDelay( 0 )
		_GModText_AllowOffscreen( false )
	_GModText_Send( userid, key )
	
		
	_GModText_Start( font );
		_GModText_SetPos( posx, posy )
		_GModText_SetColor( r, g, b, 255 )
		_GModText_AllowOffscreen( false )
	_GModText_SendAnimate( userid, key, length, ease );
end

-- sendRect - creates a rectangle in the specified format ( used for menus )
function sendRect( userid, key, rectBegX, rectBegY1, rectBegSizeX, rectBegSizeY, r, g, b, a, material, timeout, fadein, fadeout )
	_GModRect_Start( material )
		_GModRect_SetPos( rectBegX, rectBegY1, rectBegSizeX, rectBegSizeY )
		_GModRect_SetColor( r, g, b, a )
		_GModRect_SetTime( timeout, fadein, fadeout )
		_GModRect_SetDelay( 0 )
	_GModRect_Send( userid, key )
end

-- sendRectAnimate - animates the rectangle ( you have to define the text with sendRect or sendRectAndAnimate first! )
function sendRectAnimate( userid, key, rectEndX, rectEndY, rectEndSizeX, rectEndSizeY, r, g, b, a, material, length, ease )
	_GModRect_Start( material );
		_GModRect_SetPos( rectEndX, rectEndY, rectEndSizeX, rectEndSizeY )
		_GModRect_SetColor( r, g, b, a )
	_GModRect_SendAnimate( userid, key, length, ease )
end

-- sendRectAndAnimate - sends and animates the rectangle in the specified format ( used for menus )
function sendRectAndAnimate( userid, key, rectBegX, rectBegY1, rectBegSizeX, rectBegSizeY, rectEndX, rectEndY, rectEndSizeX, rectEndSizeY, r, g, b, a, material, timeout, fadein, fadeout, length, ease )
	_GModRect_Start( material )
		_GModRect_SetPos( rectBegX, rectBegY1, rectBegSizeX, rectBegSizeY )
		_GModRect_SetColor( r, g, b, a )
		_GModRect_SetTime( timeout, fadein, fadeout )
		_GModRect_SetDelay( 0 )
	_GModRect_Send( userid, key )
	
	_GModRect_Start( material );
		_GModRect_SetPos( rectEndX, rectEndY, rectEndSizeX, rectEndSizeY )
		_GModRect_SetColor( r, g, b, a )
	_GModRect_SendAnimate( userid, key, length, ease )
end

-- This comes from lua.org, thanks for teaching millions lua, and providing this awesome code!

List = {}
function List.new ()
	return {first = 0, last = -1}
end


function List.pushleft (list, value)
	local first = list.first - 1
	list.first = first
	list[first] = value
end
    
function List.pushright (list, value)
	local last = list.last + 1
	list.last = last
	list[last] = value
end
    
function List.popleft (list)
	local first = list.first
	if first > list.last then error("list is empty") end
	local value = list[first]
	list[first] = nil        -- to allow garbage collection
	list.first = first + 1
	return value
end
    
function List.popright (list)
	local last = list.last
	if list.first > last then error("list is empty") end
	local value = list[last]
	list[last] = nil         -- to allow garbage collection
	list.last = last - 1
	return value
end
